@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# BloGTK Version 1.0
+# BloGTK Version 1.1
 # (C)2004 Jay Reding
 # Code released under the terms of the BSD License. (See file LICENSE)
 # This program allows users to post to various weblog systems without starting a
@@ -34,6 +34,11 @@ import proxy
 
 foo = 0
 
+# 1.1 - I should also make a global variable for the version number so that I don't
+# have to constantly be changing strings.
+
+version = "1.1"
+
 class BloGTK:
 
    def delete_event(self, widget, event, data=None):
@@ -545,7 +550,8 @@ class BloGTK:
 
       text = self.blogCombo.entry.get_text()
 
-      self.mainWindow.set_title("BloGTK 1.0 - " + text)
+      # 1.1 - Make sure we pull our version string rather than having to manually update each release.
+      self.mainWindow.set_title("BloGTK " + version + " - " + text)
 
    def getCategories(self, widget, foo):
 
@@ -695,11 +701,11 @@ class BloGTK:
 
    def insertTag_Bold(self, widget):
       
-      self.tagInsertionLogic(widget, "<b>","</b>")
+      self.tagInsertionLogic(widget, "<strong>","</strong>")
 
    def insertTag_Italic(self, widget):
 
-      self.tagInsertionLogic(widget, "<i>", "</i>")
+      self.tagInsertionLogic(widget, "<em>", "</em>")
 
    def insertTag_Uline(self, widget):
 
@@ -711,19 +717,19 @@ class BloGTK:
 
    def insertTag_Left(self, widget):
 
-      self.tagInsertionLogic(widget, "<div align=\"left\">", "</div>")
+      self.tagInsertionLogic(widget, "<div style=\"text-align: left;\">", "</div>")
 
    def insertTag_Center(self, widget):
 
-      self.tagInsertionLogic(widget, "<div align=\"center\">", "</div>")
+      self.tagInsertionLogic(widget, "<div style=\"text-align: center;\">", "</div>")
 
    def insertTag_Right(self, widget):
 
-      self.tagInsertionLogic(widget, "<div align=\"right\">", "</div>")
+      self.tagInsertionLogic(widget, "<div style=\"text-align: right;\">", "</div>")
 
    def insertTag_Fill(self, widget):
 
-     self.tagInsertionLogic(widget, "<div align=\"justify\">", "</div>")
+     self.tagInsertionLogic(widget, "<div style=\"text-align: justify;\">", "</div>")
 
    # 0.6 - More tags to insert for more fun! Hooray!
 
@@ -996,6 +1002,11 @@ class BloGTK:
       except ConfigParser.NoSectionError:
          pass
 
+      try:
+         script_tag = config.get(tag_name, "script_tag")
+      except ConfigParser.NoSectionError:
+         pass
+
       try:
          end_tag = config.get(tag_name, "end_tag")
       except ConfigParser.NoSectionError:
@@ -1016,10 +1027,13 @@ class BloGTK:
       selMark = self.buffer.get_selection_bound()
       insMark = self.buffer.get_insert()
 
+      child = os.popen(script_tag)
+      script_output = child.read()
+
       try:
          start, end = self.buffer.get_selection_bounds()
          text = self.buffer.get_text(start, end)
-         new_text = start_tag + text + end_tag
+         new_text = start_tag + script_output + text + end_tag
          self.buffer.delete(start, end)
          self.buffer.insert(start, new_text, -1)
          cur_pos = self.buffer.get_iter_at_mark(self.buffer.get_insert())
@@ -1027,7 +1041,7 @@ class BloGTK:
          self.buffer.move_mark(selMark, match_end)
          self.buffer.move_mark(insMark, match_start)
       except:
-         self.buffer.insert_at_cursor(start_tag + end_tag, -1)
+         self.buffer.insert_at_cursor(start_tag + script_output + end_tag, -1)
 	 end = self.buffer.get_iter_at_mark(selMark)
 	 cur_point = len(end_tag)
 	 end.backward_chars(cur_point)
