@@ -305,7 +305,10 @@ def mt_sendPostToWindow(foo, mainGlade, result, selection, url, user, passwd, rp
             postId = item['postid']
             extended = item['mt_text_more']
             excerpt = item['mt_excerpt']
-            keywords = item['mt_keywords']
+            try:
+		keywords = item['mt_keywords']	
+            except:
+		pass
          
    titleEntry.set_text(postTitle)
 
@@ -324,8 +327,11 @@ def mt_sendPostToWindow(foo, mainGlade, result, selection, url, user, passwd, rp
    buffer3.set_text(excerpt)
    excerptView.set_buffer(buffer3)
 
-   keywordsEntry.set_text(keywords)
-
+   try:
+      keywordsEntry.set_text(keywords)
+   except:
+      pass
+	  
    postIDLabel.set_text(postId)
 
    # 0.4 - Now we need to retrieve the list of categories that the post belongs
